@@ -1,7 +1,7 @@
 package Complete::Getopt::Long;
 
-our $DATE = '2016-02-03'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2016-09-27'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use strict;
@@ -133,12 +133,12 @@ $SPEC{complete_cli_arg} = {
     description => <<'_',
 
 This routine can complete option names, where the option names are retrieved
-from `Getopt::Long` specification. If you provide completion routine in
+from <pm:Getopt::Long> specification. If you provide completion routine in
 `completion`, you can also complete _option values_ and _arguments_.
 
-Note that this routine does not use `Getopt::Long` (it does its own parsing) and
-currently is not affected by Getopt::Long's configuration. Its behavior mimics
-Getopt::Long under these configuration: `no_ignore_case`, `bundling` (or
+Note that this routine does not use <pm:Getopt::Long> (it does its own parsing)
+and currently is not affected by Getopt::Long's configuration. Its behavior
+mimics Getopt::Long under these configuration: `no_ignore_case`, `bundling` (or
 `no_bundling` if the `bundling` option is turned off). Which I think is the
 sensible default. This routine also does not currently support `auto_help` and
 `auto_version`, so you'll need to add those options specifically if you want to
@@ -178,7 +178,8 @@ as well as all keys from `extras` (but these won't override the above keys).
 and is expected to return a completion answer structure as described in
 `Complete` which is either a hash or an array. The simplest form of answer is
 just to return an array of strings. The various `complete_*` function like those
-in `Complete::Util` or the other `Complete::*` modules are suitable to use here.
+in <pm:Complete::Util> or the other `Complete::*` modules are suitable to use
+here.
 
 Completion routine can also return undef to express declination, in which case
 the default completion routine will then be consulted. The default routine
@@ -213,7 +214,7 @@ _
             summary     => 'Command line arguments, like @ARGV',
             description => <<'_',
 
-See function `parse_cmdline` in `Complete::Bash` on how to produce this (if
+See function `parse_cmdline` in <pm:Complete::Bash> on how to produce this (if
 you're using bash).
 
 _
@@ -225,7 +226,7 @@ _
                 "Index in words of the word we're trying to complete",
             description => <<'_',
 
-See function `parse_cmdline` in `Complete::Bash` on how to produce this (if
+See function `parse_cmdline` in <pm:Complete::Bash> on how to produce this (if
 you're using bash).
 
 _
@@ -267,7 +268,7 @@ _
         schema => ['any*' => of => ['hash*', 'array*']],
         description => <<'_',
 
-You can use `format_completion` function in `Complete::Bash` module to format
+You can use `format_completion` function in <pm:Complete::Bash> module to format
 the result of this function for bash.
 
 _
@@ -557,7 +558,7 @@ sub complete_cli_arg {
         );
         $log->tracef('[comp][compgl] invoking \'completion\' routine '.
                          'to complete argument');
-        my $compres = $comp->(%compargs);
+        my $compres = $comp->(%compargs) if $comp;
         if (!defined $compres) {
             $compres = _default_completion(%compargs);
             $log->tracef('[comp][compgl] adding result from default '.
@@ -589,7 +590,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.41 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2016-02-03.
+This document describes version 0.42 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2016-09-27.
 
 =head1 SYNOPSIS
 
@@ -608,12 +609,12 @@ Options that differ only in case often are often and they mean different things.
 Complete command-line argument using Getopt::Long specification.
 
 This routine can complete option names, where the option names are retrieved
-from C<Getopt::Long> specification. If you provide completion routine in
+from L<Getopt::Long> specification. If you provide completion routine in
 C<completion>, you can also complete I<option values> and I<arguments>.
 
-Note that this routine does not use C<Getopt::Long> (it does its own parsing) and
-currently is not affected by Getopt::Long's configuration. Its behavior mimics
-Getopt::Long under these configuration: C<no_ignore_case>, C<bundling> (or
+Note that this routine does not use L<Getopt::Long> (it does its own parsing)
+and currently is not affected by Getopt::Long's configuration. Its behavior
+mimics Getopt::Long under these configuration: C<no_ignore_case>, C<bundling> (or
 C<no_bundling> if the C<bundling> option is turned off). Which I think is the
 sensible default. This routine also does not currently support C<auto_help> and
 C<auto_version>, so you'll need to add those options specifically if you want to
@@ -674,7 +675,8 @@ as well as all keys from C<extras> (but these won't override the above keys).
 and is expected to return a completion answer structure as described in
 C<Complete> which is either a hash or an array. The simplest form of answer is
 just to return an array of strings. The various C<complete_*> function like those
-in C<Complete::Util> or the other C<Complete::*> modules are suitable to use here.
+in L<Complete::Util> or the other C<Complete::*> modules are suitable to use
+here.
 
 Completion routine can also return undef to express declination, in which case
 the default completion routine will then be consulted. The default routine
@@ -707,7 +709,7 @@ Example:
 
 Index in words of the word we're trying to complete.
 
-See function C<parse_cmdline> in C<Complete::Bash> on how to produce this (if
+See function C<parse_cmdline> in L<Complete::Bash> on how to produce this (if
 you're using bash).
 
 =item * B<extras> => I<hash>
@@ -726,7 +728,7 @@ Getopt::Long specification.
 
 Command line arguments, like @ARGV.
 
-See function C<parse_cmdline> in C<Complete::Bash> on how to produce this (if
+See function C<parse_cmdline> in L<Complete::Bash> on how to produce this (if
 you're using bash).
 
 =back
@@ -734,7 +736,7 @@ you're using bash).
 Return value:  (hash|array)
 
 
-You can use C<format_completion> function in C<Complete::Bash> module to format
+You can use C<format_completion> function in L<Complete::Bash> module to format
 the result of this function for bash.
 
 =head1 HOMEPAGE
